pub trait OApiCheckTrait {
// Required method
fn oapi_check_inner(
&self,
state: &SparseRoot<OApiDocument>,
bread_crumb: &mut Vec<String>,
) -> Result<(), OApiError>;
// Provided method
fn oapi_check(
&self,
state: &SparseRoot<OApiDocument>,
bread_crumb: &mut Vec<String>,
) -> Result<(), OApiError> { ... }
}Expand description
Check trait for OApi
This trait allows struct of the OApi crates and extensions to be validated at runtime for logic errors
Required Methods
Sourcefn oapi_check_inner(
&self,
state: &SparseRoot<OApiDocument>,
bread_crumb: &mut Vec<String>,
) -> Result<(), OApiError>
fn oapi_check_inner( &self, state: &SparseRoot<OApiDocument>, bread_crumb: &mut Vec<String>, ) -> Result<(), OApiError>
Check every inner attributes of the object
Provided Methods
Sourcefn oapi_check(
&self,
state: &SparseRoot<OApiDocument>,
bread_crumb: &mut Vec<String>,
) -> Result<(), OApiError>
fn oapi_check( &self, state: &SparseRoot<OApiDocument>, bread_crumb: &mut Vec<String>, ) -> Result<(), OApiError>
Check the current object, if any checks are to be performed, then checks its inner attributes
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".